This directory holds custom python typing stub files for third-party libraries
that do not include their own type hints.

These stubs help improve code completion and type checking in IDEs and type
checkers like mypy.

To use these stubs, ensure that your IDE or type checker is configured to
recognize the `typings` directory as a source of type information.
For VSCode, this should be automatic.
